==> navigaattori-2023.1.14.tar.gz: navigaattori-2023.1.14/README.md <==
# Navigaattori

Navigator (Finnish: navigaattori) guided by conventions.

[License: MIT](https://git.sr.ht/~sthagen/navigaattori/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](third-party/README.md).

[![version](https://img.shields.io/pypi/v/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)
[![downloads](https://pepy.tech/badge/navigaattori/month)](https://pepy.tech/project/navigaattori)
[![wheel](https://img.shields.io/pypi/wheel/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)
[![supported-versions](https://img.shields.io/pypi/pyversions/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)
[![supported-implementations](https://img.shields.io/pypi/implementation/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)

## Documentation

User and developer [documentation of navigaattori](https://codes.dilettant.life/docs/navigaattori).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of navigaattori](https://todo.sr.ht/~sthagen/navigaattori).

## Primary Source repository

The main source of `navigaattori` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `navigaattori` are:

* [on codeberg](https://codeberg.org/sthagen/navigaattori) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/navigaattori) - a collection of tools useful for software development.

# Status

Experimental.

**Note**: The default branch is `default`.

==> navigaattori-2023.6.18.tar.gz: navigaattori-2023.6.18/README.md <==
# Navigaattori

Navigator (Finnish: navigaattori) guided by conventions.

[License: MIT](https://git.sr.ht/~sthagen/navigaattori/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)
[![downloads](https://pepy.tech/badge/navigaattori/month)](https://pepy.tech/project/navigaattori)
[![wheel](https://img.shields.io/pypi/wheel/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)
[![supported-versions](https://img.shields.io/pypi/pyversions/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)
[![supported-implementations](https://img.shields.io/pypi/implementation/navigaattori.svg?style=flat)](https://pypi.python.org/pypi/navigaattori/)

## Documentation

User and developer [documentation of navigaattori](https://codes.dilettant.life/docs/navigaattori).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of navigaattori](https://todo.sr.ht/~sthagen/navigaattori).

## Primary Source repository

The main source of `navigaattori` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `navigaattori` are:

* [on codeberg](https://codeberg.org/sthagen/navigaattori) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/navigaattori) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

# Status

Experimental.

**Note**: The default branch is `default`.
